@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,7 +61,7 @@ import com.openexchange.config.ConfigurationService;
 
 public abstract class AbstractConfigWrapper {
 
-    private static final Log LOG = LogFactory.getLog(AbstractConfigWrapper.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AbstractConfigWrapper.class));
 
     public static String parseProperty(final ConfigurationService prop, final String name, final String value) {
         final String tmp = prop.getProperty(name, "");
