@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,13 +49,14 @@
 
 package com.openexchange.push.udp;
 
+import java.util.Arrays;
 import java.util.Date;
 import com.openexchange.tools.StringCollection;
 
 /**
  * {@link PushObject} - The push object.
  * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public class PushObject extends AbstractPushObject {
 
@@ -81,13 +82,11 @@ public class PushObject extends AbstractPushObject {
      * @param isRemote <code>true</code> to mark this push object as remotely received; otherwise <code>false</code>
      */
     public PushObject(final int folderId, final int module, final int contextId, final int[] users, final boolean isRemote, final long timestamp) {
-        super();
+        super(contextId, isRemote);
         this.folderId = folderId;
         this.module = module;
-        this.contextId = contextId;
         this.users = users;
-        this.remote = isRemote;
-        this.hash = hashCode0();
+        hash = hashCode0();
         this.timestamp = timestamp;
     }
 
@@ -96,6 +95,7 @@ public class PushObject extends AbstractPushObject {
         int result = super.hashCode();
         result = prime * result + folderId;
         result = prime * result + module;
+        result = prime * result + Arrays.hashCode(users);
         return result;
     }
 
@@ -146,33 +146,45 @@ public class PushObject extends AbstractPushObject {
 
     @Override
     public int hashCode() {
+        final int prime = 31;
+        int result = super.hashCode();
+        result = prime * result + folderId;
+        result = prime * result + module;
+        result = prime * result + Arrays.hashCode(users);
+        return result;
+    }
+
+    public int hashCode1() {
         return hash;
     }
 
     @Override
-    public boolean equals(final Object obj) {
+    public boolean equals(Object obj) {
         if (this == obj) {
             return true;
         }
         if (!super.equals(obj)) {
             return false;
         }
-        if (!(obj instanceof PushObject)) {
+        if (getClass() != obj.getClass()) {
             return false;
         }
-        final PushObject other = (PushObject) obj;
+        PushObject other = (PushObject) obj;
         if (folderId != other.folderId) {
             return false;
         }
         if (module != other.module) {
             return false;
         }
+        if (!Arrays.equals(users, other.users)) {
+            return false;
+        }
         return true;
     }
 
     @Override
     public String toString() {
         return new StringBuilder().append("FOLDER_ID=").append(folderId).append(",MODULE=").append(module).append(",CONTEXT_ID=").append(
-            contextId).append(",USERS=").append(StringCollection.convertArray2String(users)).append(",IS_REMOTE=").append(remote).toString();
+            getContextId()).append(",USERS=").append(StringCollection.convertArray2String(users)).append(",IS_REMOTE=").append(isRemote()).toString();
     }
 }
