@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,9 +54,9 @@ import org.apache.commons.logging.LogFactory;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
-import com.openexchange.push.udp.PushConfig;
-import com.openexchange.push.udp.PushInit;
+import com.openexchange.push.udp.PushConfiguration;
 import com.openexchange.push.udp.PushDiscoverySender;
+import com.openexchange.push.udp.PushInit;
 import com.openexchange.timer.TimerService;
 
 /**
@@ -66,7 +66,7 @@ import com.openexchange.timer.TimerService;
  */
 public final class TimerCustomizer implements ServiceTrackerCustomizer {
 
-    private static final Log LOG = LogFactory.getLog(TimerCustomizer.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(TimerCustomizer.class));
 
     private final BundleContext context;
 
@@ -75,14 +75,14 @@ public final class TimerCustomizer implements ServiceTrackerCustomizer {
     /**
      * Initializes a new {@link TimerCustomizer}.
      */
-    public TimerCustomizer(BundleContext context) {
+    public TimerCustomizer(final BundleContext context) {
         super();
         this.context = context;
     }
 
-    public Object addingService(ServiceReference reference) {
-        TimerService timer = (TimerService) context.getService(reference);
-        PushConfig config = PushInit.getInstance().getConfig();
+    public Object addingService(final ServiceReference reference) {
+        final TimerService timer = (TimerService) context.getService(reference);
+        final PushConfiguration config = PushInit.getInstance().getConfig();
         if (config.isMultiCastEnabled()) {
             LOG.info("Starting push multicast discovery sender.");
             sender = new PushDiscoverySender(config);
@@ -93,11 +93,11 @@ public final class TimerCustomizer implements ServiceTrackerCustomizer {
         return timer;
     }
 
-    public void modifiedService(ServiceReference reference, Object service) {
+    public void modifiedService(final ServiceReference reference, final Object service) {
         // Nothing to do.
     }
 
-    public void removedService(ServiceReference reference, Object service) {
+    public void removedService(final ServiceReference reference, final Object service) {
         if (null != sender) {
             LOG.info("Stopping push multicast discovery sender.");
             sender.stopSender();
